@@ -18,19 +18,20 @@ class PlasmaShell;
 }
 }
 
+class WindowManagement;
+
 class WindowSystem : public QObject, public KWindowSystemPrivateV2
 {
     Q_OBJECT
 public:
     WindowSystem();
+    ~WindowSystem() override;
     QList<WId> windows() override;
     QList<WId> stackingOrder() override;
     WId activeWindow() override;
     void activateWindow(WId win, long time) override;
     void forceActiveWindow(WId win, long time) override;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
     void demandAttention(WId win, bool set) override;
-#endif
     void requestToken(QWindow *win, uint32_t serial, const QString &app_id) override;
     quint32 lastInputSerial(QWindow *window) override;
     void setCurrentToken(const QString &token) override;
@@ -41,14 +42,10 @@ public:
     void setOnAllDesktops(WId win, bool b) override;
     void setOnDesktop(WId win, int desktop) override;
     void setOnActivities(WId win, const QStringList &activities) override;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
     WId transientFor(WId window) override;
     WId groupLeader(WId window) override;
-#endif
     QPixmap icon(WId win, int width, int height, bool scale, int flags) override;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
     void setIcons(WId win, const QPixmap &icon, const QPixmap &miniIcon) override;
-#endif
     void setType(WId win, NET::WindowType windowType) override;
     void setState(WId win, NET::States state) override;
     void clearState(WId win, NET::States state) override;
@@ -82,6 +79,7 @@ public:
     QString readNameProperty(WId window, unsigned long atom) override;
     void allowExternalProcessWindowActivation(int pid) override;
     void setBlockingCompositing(WId window, bool active) override;
+
     bool mapViewport() override;
     int viewportToDesktop(const QPoint &pos) override;
     int viewportWindowToDesktop(const QRect &r) override;
@@ -92,6 +90,7 @@ public:
 private:
     KWayland::Client::PlasmaShell *m_waylandPlasmaShell = nullptr;
     QString m_lastToken;
+    WindowManagement *m_windowManagement;
 };
 
 #endif
